@@ -1,6 +1,8 @@
 from typing import List, Optional, Dict, Tuple, Union
 from ..application.assembler import Assembler
 from .entity import (
+    APIGatewayBlacklistItem,
+    APIGatewayRequest,
     BootstrapInfo,
     ClusterConfig,
     ClusterConfigData,
@@ -11,6 +13,8 @@ from .entity import (
     RandomTemplateVariables
 )
 from .dto import (
+    APIGatewayBlacklistItemDTO,
+    APIGatewayRequestDTO,
     BootstrapInfoDTO,
     ClusterConfigDTO,
     ClusterConfigDataDTO,
@@ -161,3 +165,49 @@ class FilesTemplateVariablesAssembler(Assembler):
             paths = [m.get_value() for m in x.paths]
         )
 files_template_variables_assembler=FilesTemplateVariablesAssembler()
+
+
+
+class APIGatewayRequestAssembler(Assembler):
+    def to_entity(self, dto: APIGatewayRequestDTO):
+        return APIGatewayRequest(
+            service_name = UStr(dto.service_name),
+            method = UStr(dto.method),
+            ip = None if dto.ip is None else UStr(dto.ip),
+            port = None if dto.port is None else UInt(dto.port),
+            route = None if dto.route is None else UStr(dto.route),
+            action = None if dto.action is None else UStr(dto.action),
+            auth = None if dto.auth is None else UDict(dto.auth),
+            data = None if dto.data is None else UDict(dto.data)
+        )
+    def to_dto(self, x:APIGatewayRequest):
+        return APIGatewayRequestDTO(
+            service_name = x.service_name.get_value(),
+            method = x.method.get_value(),
+            ip = None if x.ip is None else x.ip.get_value(),
+            port = None if x.port is None else x.port.get_value(),
+            route = None if x.route is None else x.route.get_value(),
+            action = None if x.action is None else x.action.get_value(),
+            auth = None if x.auth is None else x.auth.get_value(),
+            data = None if x.data is None else x.data.get_value()
+        )
+api_gateway_request_assembler=APIGatewayRequestAssembler()
+
+
+
+class APIGatewayBlacklistItemAssembler(Assembler):
+    def to_entity(self, dto: APIGatewayBlacklistItemDTO):
+        return APIGatewayBlacklistItem(
+            ip = UStr(dto.ip),
+            creation_time = UStr(dto.creation_time),
+            limit_time = UInt(dto.limit_time),
+            limit_reason = UStr(dto.limit_reason)
+        )
+    def to_dto(self, x:APIGatewayBlacklistItem):
+        return APIGatewayBlacklistItemDTO(
+            ip = x.ip.get_value(),
+            creation_time = x.creation_time.get_value(),
+            limit_time = x.limit_time.get_value(),
+            limit_reason = x.limit_reason.get_value()
+        )
+api_gateway_blacklist_item_assembler=APIGatewayBlacklistItemAssembler()
