@@ -1,6 +1,8 @@
 from typing import List, Optional, Dict, Tuple, Union
 from ..infrastructure.converter import Converter
 from .entity import (
+    APIGatewayBlacklistItem,
+    APIGatewayRequest,
     BootstrapInfo,
     ClusterConfig,
     ClusterConfigData,
@@ -11,6 +13,8 @@ from .entity import (
     RandomTemplateVariables
 )
 from .do import (
+    APIGatewayBlacklistItemDO,
+    APIGatewayRequestDO,
     BootstrapInfoDO,
     ClusterConfigDO,
     ClusterConfigDataDO,
@@ -161,3 +165,49 @@ class FilesTemplateVariablesConverter(Converter):
             paths = [m.get_value() for m in x.paths]
         )
 files_template_variables_converter=FilesTemplateVariablesConverter()
+
+
+
+class APIGatewayRequestConverter(Converter):
+    def to_entity(self, do: APIGatewayRequestDO):
+        return APIGatewayRequest(
+            service_name = UStr(do.service_name),
+            method = UStr(do.method),
+            ip = None if do.ip is None else UStr(do.ip),
+            port = None if do.port is None else UInt(do.port),
+            route = None if do.route is None else UStr(do.route),
+            action = None if do.action is None else UStr(do.action),
+            auth = None if do.auth is None else UDict(do.auth),
+            data = None if do.data is None else UDict(do.data)
+        )
+    def to_do(self, x:APIGatewayRequest):
+        return APIGatewayRequestDO(
+            service_name = x.service_name.get_value(),
+            method = x.method.get_value(),
+            ip = None if x.ip is None else x.ip.get_value(),
+            port = None if x.port is None else x.port.get_value(),
+            route = None if x.route is None else x.route.get_value(),
+            action = None if x.action is None else x.action.get_value(),
+            auth = None if x.auth is None else x.auth.get_value(),
+            data = None if x.data is None else x.data.get_value()
+        )
+api_gateway_request_converter=APIGatewayRequestConverter()
+
+
+
+class APIGatewayBlacklistItemConverter(Converter):
+    def to_entity(self, do: APIGatewayBlacklistItemDO):
+        return APIGatewayBlacklistItem(
+            ip = UStr(do.ip),
+            creation_time = UStr(do.creation_time),
+            limit_time = UInt(do.limit_time),
+            limit_reason = UStr(do.limit_reason)
+        )
+    def to_do(self, x:APIGatewayBlacklistItem):
+        return APIGatewayBlacklistItemDO(
+            ip = x.ip.get_value(),
+            creation_time = x.creation_time.get_value(),
+            limit_time = x.limit_time.get_value(),
+            limit_reason = x.limit_reason.get_value()
+        )
+api_gateway_blacklist_item_converter=APIGatewayBlacklistItemConverter()
