@@ -55,4 +55,24 @@ class FileTemplateVariablesDO(BaseModel):
 
 class FilesTemplateVariablesDO(BaseModel):
     variables: List[str]
-    paths: List[str]
\ No newline at end of file
+    paths: List[str]
+
+
+
+class APIGatewayRequestDO(BaseModel):
+    service_name: str
+    method: str
+    ip: Optional[str] = None
+    port: Optional[int] = None
+    route: Optional[str] = None
+    action: Optional[str] = None
+    auth: Optional[Dict] = None
+    data: Optional[Dict] = None
+
+
+
+class APIGatewayBlacklistItemDO(BaseModel):
+    ip: str
+    creation_time: str
+    limit_time: int
+    limit_reason: str
\ No newline at end of file
