@@ -157,4 +157,54 @@ class FilesTemplateVariables(Entity):
         del all_args['kwargs']
         super().__init__(**all_args)
         self.variables = variables
-        self.paths = paths
\ No newline at end of file
+        self.paths = paths
+
+
+
+class APIGatewayRequest(Entity):
+    def __init__(
+        self,
+        service_name: UStr,
+        method: UStr,
+        ip: Optional[UStr] = None,
+        port: Optional[UInt] = None,
+        route: Optional[UStr] = None,
+        action: Optional[UStr] = None,
+        auth: Optional[UDict] = None,
+        data: Optional[UDict] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.service_name = service_name
+        self.method = method
+        self.ip = ip
+        self.port = port
+        self.route = route
+        self.action = action
+        self.auth = auth
+        self.data = data
+
+
+
+class APIGatewayBlacklistItem(Entity):
+    def __init__(
+        self,
+        ip: UStr,
+        creation_time: UStr,
+        limit_time: UInt,
+        limit_reason: UStr,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.ip = ip
+        self.creation_time = creation_time
+        self.limit_time = limit_time
+        self.limit_reason = limit_reason
\ No newline at end of file
